@@ -1,4 +1,4 @@
-from sys import path
+from sys import path, version_info
 from pathlib import Path
 path.append(str(Path(__file__).parent.resolve()))
 from JFIFDecoder import decode as JFIF_decoder
@@ -9,7 +9,10 @@ from skimage.io import imread
 
 JFIF_FILE_TEST_SIZE = 11
 def read_image(path: str) -> ndarray:
-    read_failed = False
+    py_ver = True
+    if not (version_info.major == 3 and version_info.minor == 7 and version_info.micro == 7):
+        py_ver = False
+    read_not_failed = True
     raw_img = list
     img = ndarray
 
@@ -20,13 +23,13 @@ def read_image(path: str) -> ndarray:
         try:
             raw_img = JFIF_decoder(image)
         except:
-            read_failed = True
+            read_not_failed = False
     else:
-        read_failed = True
+        read_not_failed = False
 
-    if read_failed:
-        img = imread(path)
-    else:
+    if read_not_failed and py_ver:
         img = asarray(raw_img)
+    else:
+        img = imread(path)
 
     return img
